![django-secure-passwords logo](https://github.com/Blueshoe/django-secure-passwords/raw/master/docs/_static/img/logo.png)

--------------------------------------------------------------------------------
![Build Status](https://github.com/Blueshoe/django-secure-passwords/actions/workflows/python-app.yml/badge.svg)
[![Quality Gate Status](https://sonarcloud.io/api/project_badges/measure?project=Blueshoe_django-secure-passwords&metric=alert_status)](https://sonarcloud.io/dashboard?id=Blueshoe_django-secure-passwords)
[![Coverage Status](https://coveralls.io/repos/github/Blueshoe/django-secure-passwords/badge.svg?branch=master)](https://coveralls.io/github/Blueshoe/django-secure-passwords?branch=master)
[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)
[![License: MIT](https://img.shields.io/badge/License-MIT-yellow.svg)](https://opensource.org/licenses/MIT)


**Todo**


## Installation

django-secure-passwords is currently available only on Blueshoe's Python Package Index.
```bash
pip3 install django-secure-passwords
```

Add *"django-secure-passwords"* to your *INSTALLED_APPS*: 
```python
INSTALLED_APPS = [
    "...",
    "securepasswords",
]
```

## Usage

# TODO prettify
Recommended: usage of `AbstractBaseUser` subclass as `AUTH_USER_MODEL`

